@@ -23,27 +23,24 @@
 #include "k3bexternalbinmanager.h"
 #include "k3bcore.h"
 #include "k3bmediacache.h"
+#include "k3bmsf.h"
+#include "k3b_i18n.h"
 
-#include <kdeversion.h>
-#include <kglobal.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <kapplication.h>
-#include <kdebug.h>
-#include <kio/job.h>
-#include <kio/netaccess.h>
-#include <kurl.h>
-#include <kprocess.h>
-#include <KDiskFreeSpaceInfo>
-
-#include <kmountpoint.h>
+#include <KCoreAddons/KProcess>
+#include <KIOCore/KDiskFreeSpaceInfo>
+#include <KIOCore/KIO/Job>
+#include <KIOCore/KIO/StatJob>
+#include <KIOCore/KMountPoint>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 #include <Solid/OpticalDrive>
 
-#include <qdatastream.h>
-#include <qdir.h>
-#include <qfile.h>
+#include <QtCore/QDataStream>
+#include <QtCore/QDebug>
+#include <QtCore/QDir>
+#include <QtCore/QFile>
+#include <QtCore/QStandardPaths>
+#include <QtCore/QUrl>
 
 #include <cmath>
 #include <sys/utsname.h>
@@ -147,7 +144,7 @@ QString K3b::parentDir( const QString& path )
     if( pos >= 0 )
         parent.truncate( pos+1 );
     else // relative path, do anything...
-        parent = "/";
+        parent = '/';
 
     return parent;
 }
@@ -181,10 +178,10 @@ K3b::Version K3b::kernelVersion()
     utsname unameinfo;
     if( ::uname(&unameinfo) == 0 ) {
         v = QString::fromLocal8Bit( unameinfo.release );
-        kDebug() << "kernel version: " << v;
+        qDebug() << "kernel version: " << v;
     }
     else
-        kError() << "could not determine kernel version." ;
+        qCritical() << "could not determine kernel version." ;
     return v;
 }
 
@@ -203,7 +200,7 @@ QString K3b::systemName()
         v = QString::fromLocal8Bit( unameinfo.sysname );
     }
     else
-        kError() << "could not determine system name." ;
+        qCritical() << "could not determine system name." ;
     return v;
 }
 
@@ -222,7 +219,7 @@ bool K3b::kbFreeOnFs( const QString& path, unsigned long& size, unsigned long& a
 }
 
 
-KIO::filesize_t K3b::filesize( const KUrl& url )
+KIO::filesize_t K3b::filesize( const QUrl& url )
 {
     KIO::filesize_t fSize = 0;
     if( url.isLocalFile() ) {
@@ -231,7 +228,9 @@ KIO::filesize_t K3b::filesize( const KUrl& url )
     }
     else {
         KIO::UDSEntry uds;
-        KIO::NetAccess::stat( url, uds, 0 );
+        KIO::StatJob* statJob = KIO::stat( url, KIO::HideProgressInfo );
+        if (statJob->exec())
+            uds = statJob->statResult();
         fSize = uds.numberValue( KIO::UDSEntry::UDS_SIZE );
     }
 
@@ -239,12 +238,20 @@ KIO::filesize_t K3b::filesize( const KUrl& url )
 }
 
 
-KIO::filesize_t K3b::imageFilesize( const KUrl& url )
+KIO::filesize_t K3b::imageFilesize( const QUrl& url )
 {
     KIO::filesize_t size = K3b::filesize( url );
-    int cnt = 0;
-    while( KIO::NetAccess::exists( url.url() + '.' + QString::number(cnt).rightJustified( 3, '0' ), KIO::NetAccess::SourceSide, 0 ) )
-        size += K3b::filesize( url.url() + '.' + QString::number(cnt++).rightJustified( 3, '0' ) );
+    bool exists = true;
+    for(int cnt = 0; exists; ++cnt)
+    {
+        QUrl nextUrl( url );
+        nextUrl.setPath(nextUrl.path() + '.' + QString::number(cnt).rightJustified( 3, '0' ));
+        KIO::StatJob* statJob = KIO::stat(nextUrl, KIO::StatJob::SourceSide, KIO::HideProgressInfo);
+        if (statJob->exec())
+            size += K3b::filesize(nextUrl);
+        else
+            exists = false;
+    }
     return size;
 }
 
@@ -331,6 +338,8 @@ K3b::WritingApp K3b::writingAppFromString( const QString& s )
         return K3b::WritingAppGrowisofs;
     else if( s.toLower() == "dvd+rw-format" )
         return K3b::WritingAppDvdRwFormat;
+    else if (s.toLower() == "cdrskin")
+        return K3b::WritingAppCdrskin;
     else
         return K3b::WritingAppAuto;
 }
@@ -369,20 +378,27 @@ QString K3b::resolveLink( const QString& file )
 }
 
 
-KUrl K3b::convertToLocalUrl( const KUrl& url )
+QUrl K3b::convertToLocalUrl( const QUrl& url )
 {
     if( !url.isLocalFile() ) {
-        return KIO::NetAccess::mostLocalUrl( url, 0 );
+        KIO::StatJob* statJob = KIO::mostLocalUrl( url, KIO::HideProgressInfo );
+        QUrl result;
+        QObject::connect( statJob, &KJob::result, [&](KJob*) {
+            if( statJob->error() == KJob::NoError )
+                result = statJob->mostLocalUrl();
+        } );
+        statJob->exec();
+        return result;
     }
 
     return url;
 }
 
 
-KUrl::List K3b::convertToLocalUrls( const KUrl::List& urls )
+QList<QUrl> K3b::convertToLocalUrls( const QList<QUrl>& urls )
 {
-    KUrl::List r;
-    for( KUrl::List::const_iterator it = urls.constBegin(); it != urls.constEnd(); ++it )
+    QList<QUrl> r;
+    for( QList<QUrl>::const_iterator it = urls.constBegin(); it != urls.constEnd(); ++it )
         r.append( convertToLocalUrl( *it ) );
     return r;
 }
@@ -421,11 +437,11 @@ qint64 K3b::fromLe64( char* data )
 QString K3b::findExe( const QString& name )
 {
     // first we search the path
-    QString bin = KStandardDirs::findExe( name );
+    QString bin = QStandardPaths::findExecutable( name );
 
     // then go on with our own little list
     if( bin.isEmpty() )
-        bin = KStandardDirs::findExe( name, k3bcore->externalBinManager()->searchPath().join(":") );
+        bin = QStandardPaths::findExecutable( name, k3bcore->externalBinManager()->searchPath() );
 
     return bin;
 }
@@ -447,13 +463,16 @@ bool K3b::unmount( K3b::Device::Device* dev )
 
     Solid::StorageAccess *sa = dev->solidStorage();
     if ( sa && sa->teardown() ){
-	    return true;
+        return true;
     }
 
     QString mntDev = dev->blockDeviceName();
 
     // first try to unmount it the standard way
-    if( KIO::NetAccess::synchronousRun( KIO::unmount( mntDev, false ), 0 ) )
+    KIO::SimpleJob* unmountJob = KIO::unmount( mntDev );
+    bool result = true;
+    QObject::connect( unmountJob, &KJob::result, [&](KJob* job){ result = ( job->error() != KJob::NoError ); } );
+    if( unmountJob->exec() && result )
         return true;
 
     QString mntPath;
@@ -499,7 +518,10 @@ bool K3b::mount( K3b::Device::Device* dev )
     QString mntDev = dev->blockDeviceName();
 
     // first try to mount it the standard way
-    if( KIO::NetAccess::synchronousRun( KIO::mount( true, 0, mntDev, false ), 0 ) )
+    KIO::SimpleJob* mountJob = KIO::mount( true, QByteArray(), mntDev, QString() );
+    bool result = true;
+    QObject::connect( mountJob, &KJob::result, [&](KJob* job){ result = ( job->error() != KJob::NoError ); } );
+    if( mountJob->exec() && result )
         return true;
 
     Solid::StorageAccess* sa = dev->solidStorage();
@@ -549,6 +571,55 @@ bool K3b::eject( K3b::Device::Device* dev )
 }
 
 
+K3b::Device::SpeedMultiplicator K3b::speedMultiplicatorForMediaType( K3b::Device::MediaType mediaType )
+{
+    if ( mediaType & K3b::Device::MEDIA_DVD_ALL ) {
+        return K3b::Device::SPEED_FACTOR_DVD;
+    }
+    else if ( mediaType & K3b::Device::MEDIA_BD_ALL ) {
+        return K3b::Device::SPEED_FACTOR_BD;
+    }
+    else {
+        return K3b::Device::SPEED_FACTOR_CD;
+    }
+}
+
+
+QString K3b::formatWritingSpeedFactor( int speed, K3b::Device::MediaType mediaType, SpeedFormat speedFormat )
+{
+    const int speedFactor = speedMultiplicatorForMediaType( mediaType );
+    int normalizedSpeed = speed;
+    int diff = normalizedSpeed%speedFactor;
+    if ( diff < 5 )
+        normalizedSpeed = speed-diff;
+    else if ( diff > speedFactor-5 )
+        normalizedSpeed = speed+speedFactor-diff;
+
+    // speed may be a float number. example: DVD+R(W): 2.4x
+    if ( mediaType & K3b::Device::MEDIA_DVD_ALL &&
+         normalizedSpeed%speedFactor > 0 &&
+         speedFormat != SpeedFormatInteger ) {
+         return QString::number( ( float )normalizedSpeed/( float )speedFactor, 'f', 1 );
+    }
+    else {
+        return QString::number( normalizedSpeed/speedFactor );
+    }
+}
+
+
+bool K3b::IsOverburnAllowed( const K3b::Msf& projectSize, const K3b::Msf& capacity )
+{
+    return IsOverburnAllowed( projectSize, capacity, Msf() );
+}
+
+
+bool K3b::IsOverburnAllowed( const Msf& projectSize, const Msf& capacity, const Msf& usedCapacity )
+{
+    return( k3bcore->globalSettings()->overburn() &&
+        (projectSize + usedCapacity) <= ( capacity.lba() + capacity.lba() / 4 ) ); // 25% tolerance in overburn mode
+}
+
+
 QDebug& K3b::operator<<( QDebug& dbg, K3b::WritingMode mode )
 {
     return dbg << K3b::Device::WritingMode( mode );
