@@ -37,20 +37,18 @@
 #include "k3bisooptions.h"
 #include "k3bdeviceglobals.h"
 #include "k3bgrowisofswriter.h"
+#include "k3b_i18n.h"
 
-#include <kapplication.h>
-#include <klocale.h>
-#include <kstandarddirs.h>
-#include <ktemporaryfile.h>
-#include <kio/global.h>
-#include <kio/job.h>
+#include <KIOCore/KIO/Global>
+#include <KIOCore/KIO/Job>
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qdatetime.h>
-#include <qfile.h>
-#include <qdatastream.h>
-#include <kdebug.h>
+#include <QtCore/QDataStream>
+#include <QtCore/QDateTime>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QTemporaryFile>
 
 
 
@@ -69,7 +67,7 @@ public:
     bool imageFinished;
     bool canceled;
 
-    KTemporaryFile* tocFile;
+    QTemporaryFile* tocFile;
 
     int usedDataMode;
     K3b::WritingApp usedWritingApp;
@@ -95,9 +93,9 @@ K3b::DataJob::DataJob( K3b::DataDoc* doc, K3b::JobHandler* hdl, QObject* parent
     d = new Private;
     d->multiSessionParameterJob = new K3b::DataMultiSessionParameterJob( doc, this, this );
     connectSubJob( d->multiSessionParameterJob,
-                   SLOT( slotMultiSessionParamterSetupDone( bool ) ),
-                   SIGNAL( newTask( const QString& ) ),
-                   SIGNAL( newSubTask( const QString& ) ) );
+                   SLOT(slotMultiSessionParamterSetupDone(bool)),
+                   SIGNAL(newTask(QString)),
+                   SIGNAL(newSubTask(QString)) );
 
     d->doc = doc;
     m_writerJob = 0;
@@ -108,7 +106,7 @@ K3b::DataJob::DataJob( K3b::DataDoc* doc, K3b::JobHandler* hdl, QObject* parent
 
 K3b::DataJob::~DataJob()
 {
-    kDebug();
+    qDebug();
     delete d->pipe;
     delete d->tocFile;
     delete d;
@@ -132,7 +130,7 @@ K3b::Device::Device* K3b::DataJob::writer() const
 
 void K3b::DataJob::start()
 {
-    kDebug();
+    qDebug();
     jobStarted();
 
     d->canceled = false;
@@ -158,7 +156,7 @@ void K3b::DataJob::start()
 
 void K3b::DataJob::slotMultiSessionParamterSetupDone( bool success )
 {
-    kDebug() << success;
+    qDebug() << success;
     if ( success ) {
         prepareWriting();
     }
@@ -174,7 +172,7 @@ void K3b::DataJob::slotMultiSessionParamterSetupDone( bool success )
 
 void K3b::DataJob::prepareWriting()
 {
-    kDebug();
+    qDebug();
     if( !d->doc->onlyCreateImages() &&
         ( d->multiSessionParameterJob->usedMultiSessionMode() == K3b::DataDoc::CONTINUE ||
           d->multiSessionParameterJob->usedMultiSessionMode() == K3b::DataDoc::FINISH ) ) {
@@ -199,7 +197,7 @@ void K3b::DataJob::prepareWriting()
 
 void K3b::DataJob::writeImage()
 {
-    kDebug();
+    qDebug();
     d->initializingImager = false;
 
     emit burning(false);
@@ -234,7 +232,7 @@ void K3b::DataJob::writeImage()
 
 void K3b::DataJob::startPipe()
 {
-    kDebug();
+    qDebug();
     //
     // Open the active pipe which does the streaming
     //
@@ -263,7 +261,7 @@ void K3b::DataJob::startPipe()
 
 bool K3b::DataJob::startOnTheFlyWriting()
 {
-    kDebug();
+    qDebug();
     if( prepareWriterJob() ) {
         if( startWriterJob() ) {
             d->initializingImager = false;
@@ -278,7 +276,7 @@ bool K3b::DataJob::startOnTheFlyWriting()
 
 void K3b::DataJob::cancel()
 {
-    kDebug();
+    qDebug();
 
     emit canceled();
 
@@ -289,7 +287,7 @@ void K3b::DataJob::cancel()
     // slotIsoImagerFinished, and slotWriterJobFinished take care of the rest
     //
     if ( active() && !cancelAll() ) {
-        kDebug() << "cancellation already done";
+        qDebug() << "cancellation already done";
         cleanup();
         jobFinished( false );
     }
@@ -298,30 +296,30 @@ void K3b::DataJob::cancel()
 
 bool K3b::DataJob::cancelAll()
 {
-    kDebug();
+    qDebug();
     bool somethingCanceled = false;
     if ( m_isoImager->active() ) {
-        kDebug() << "cancelling iso imager";
+        qDebug() << "cancelling iso imager";
         m_isoImager->cancel();
         somethingCanceled = true;
     }
     if( m_writerJob && m_writerJob->active() ) {
-        kDebug() << "cancelling writing job";
+        qDebug() << "cancelling writing job";
         m_writerJob->cancel();
         somethingCanceled = true;
     }
     if( d->verificationJob && d->verificationJob->active() ) {
-        kDebug() << "cancelling verification job";
+        qDebug() << "cancelling verification job";
         d->verificationJob->cancel();
         somethingCanceled = true;
     }
     if ( d->multiSessionParameterJob && d->multiSessionParameterJob->active() ) {
-        kDebug() << "cancelling multiSessionParameterJob";
+        qDebug() << "cancelling multiSessionParameterJob";
         d->multiSessionParameterJob->cancel();
         somethingCanceled = true;
     }
 
-    kDebug() << somethingCanceled;
+    qDebug() << somethingCanceled;
     return somethingCanceled;
 }
 
@@ -351,7 +349,7 @@ void K3b::DataJob::slotIsoImagerPercent( int p )
 
 void K3b::DataJob::slotIsoImagerFinished( bool success )
 {
-    kDebug();
+    qDebug();
     if( d->initializingImager ) {
         if( success ) {
             if( d->doc->onTheFly() && !d->doc->onlyCreateImages() ) {
@@ -435,7 +433,7 @@ void K3b::DataJob::slotIsoImagerFinished( bool success )
 
 bool K3b::DataJob::startWriterJob()
 {
-    kDebug();
+    qDebug();
     if( d->doc->dummy() )
         emit newTask( i18n("Simulating") );
     else if( d->copies > 1 )
@@ -474,7 +472,7 @@ void K3b::DataJob::slotWriterNextTrack( int t, int tt )
 
 void K3b::DataJob::slotWriterJobFinished( bool success )
 {
-    kDebug();
+    qDebug();
 
     if( success ) {
         if ( !d->doc->onTheFly() ||
@@ -498,20 +496,20 @@ void K3b::DataJob::finishCopy()
     if( d->doc->verifyData() ) {
         if( !d->verificationJob ) {
             d->verificationJob = new K3b::VerificationJob( this, this );
-            connect( d->verificationJob, SIGNAL(infoMessage(const QString&, int)),
-                     this, SIGNAL(infoMessage(const QString&, int)) );
-            connect( d->verificationJob, SIGNAL(newTask(const QString&)),
-                     this, SIGNAL(newSubTask(const QString&)) );
-            connect( d->verificationJob, SIGNAL(newSubTask(const QString&)),
-                     this, SIGNAL(newSubTask(const QString&)) );
+            connect( d->verificationJob, SIGNAL(infoMessage(QString,int)),
+                     this, SIGNAL(infoMessage(QString,int)) );
+            connect( d->verificationJob, SIGNAL(newTask(QString)),
+                     this, SIGNAL(newSubTask(QString)) );
+            connect( d->verificationJob, SIGNAL(newSubTask(QString)),
+                     this, SIGNAL(newSubTask(QString)) );
             connect( d->verificationJob, SIGNAL(percent(int)),
                      this, SLOT(slotVerificationProgress(int)) );
             connect( d->verificationJob, SIGNAL(percent(int)),
                      this, SIGNAL(subPercent(int)) );
             connect( d->verificationJob, SIGNAL(finished(bool)),
                      this, SLOT(slotVerificationFinished(bool)) );
-            connect( d->verificationJob, SIGNAL(debuggingOutput(const QString&, const QString&)),
-                     this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+            connect( d->verificationJob, SIGNAL(debuggingOutput(QString,QString)),
+                     this, SIGNAL(debuggingOutput(QString,QString)) );
 
         }
         d->verificationJob->clear();
@@ -577,7 +575,7 @@ void K3b::DataJob::slotVerificationProgress( int p )
 
 void K3b::DataJob::slotVerificationFinished( bool success )
 {
-    kDebug();
+    qDebug();
     d->copiesDone++;
 
     // reconnect our imager which we deconnected for the verification
@@ -612,28 +610,28 @@ void K3b::DataJob::slotVerificationFinished( bool success )
 
 void K3b::DataJob::setWriterJob( K3b::AbstractWriter* writer )
 {
-    kDebug();
+    qDebug();
     // FIXME: progressedsize for multiple copies
     m_writerJob = writer;
-    connect( m_writerJob, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
+    connect( m_writerJob, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
     connect( m_writerJob, SIGNAL(percent(int)), this, SLOT(slotWriterJobPercent(int)) );
-    connect( m_writerJob, SIGNAL(processedSize(int, int)), this, SIGNAL(processedSize(int, int)) );
+    connect( m_writerJob, SIGNAL(processedSize(int,int)), this, SIGNAL(processedSize(int,int)) );
     connect( m_writerJob, SIGNAL(subPercent(int)), this, SIGNAL(subPercent(int)) );
-    connect( m_writerJob, SIGNAL(processedSubSize(int, int)), this, SIGNAL(processedSubSize(int, int)) );
-    connect( m_writerJob, SIGNAL(nextTrack(int, int)), this, SLOT(slotWriterNextTrack(int, int)) );
+    connect( m_writerJob, SIGNAL(processedSubSize(int,int)), this, SIGNAL(processedSubSize(int,int)) );
+    connect( m_writerJob, SIGNAL(nextTrack(int,int)), this, SLOT(slotWriterNextTrack(int,int)) );
     connect( m_writerJob, SIGNAL(buffer(int)), this, SIGNAL(bufferStatus(int)) );
     connect( m_writerJob, SIGNAL(deviceBuffer(int)), this, SIGNAL(deviceBuffer(int)) );
-    connect( m_writerJob, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int, K3b::Device::SpeedMultiplicator)) );
+    connect( m_writerJob, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)), this, SIGNAL(writeSpeed(int,K3b::Device::SpeedMultiplicator)) );
     connect( m_writerJob, SIGNAL(finished(bool)), this, SLOT(slotWriterJobFinished(bool)) );
-    connect( m_writerJob, SIGNAL(newSubTask(const QString&)), this, SIGNAL(newSubTask(const QString&)) );
-    connect( m_writerJob, SIGNAL(debuggingOutput(const QString&, const QString&)),
-             this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+    connect( m_writerJob, SIGNAL(newSubTask(QString)), this, SIGNAL(newSubTask(QString)) );
+    connect( m_writerJob, SIGNAL(debuggingOutput(QString,QString)),
+             this, SIGNAL(debuggingOutput(QString,QString)) );
 }
 
 
 void K3b::DataJob::setImager( K3b::IsoImager* imager )
 {
-    kDebug();
+    qDebug();
     if( m_isoImager != imager ) {
         delete m_isoImager;
 
@@ -646,19 +644,19 @@ void K3b::DataJob::setImager( K3b::IsoImager* imager )
 
 void K3b::DataJob::connectImager()
 {
-    kDebug();
+    qDebug();
     m_isoImager->disconnect( this );
-    connect( m_isoImager, SIGNAL(infoMessage(const QString&, int)), this, SIGNAL(infoMessage(const QString&, int)) );
+    connect( m_isoImager, SIGNAL(infoMessage(QString,int)), this, SIGNAL(infoMessage(QString,int)) );
     connect( m_isoImager, SIGNAL(percent(int)), this, SLOT(slotIsoImagerPercent(int)) );
     connect( m_isoImager, SIGNAL(finished(bool)), this, SLOT(slotIsoImagerFinished(bool)) );
-    connect( m_isoImager, SIGNAL(debuggingOutput(const QString&, const QString&)),
-             this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
+    connect( m_isoImager, SIGNAL(debuggingOutput(QString,QString)),
+             this, SIGNAL(debuggingOutput(QString,QString)) );
 }
 
 
 void K3b::DataJob::prepareImager()
 {
-    kDebug();
+    qDebug();
     if( !m_isoImager )
         setImager( new K3b::IsoImager( d->doc, this, this ) );
 }
@@ -666,7 +664,7 @@ void K3b::DataJob::prepareImager()
 
 bool K3b::DataJob::prepareWriterJob()
 {
-    kDebug();
+    qDebug();
     if( m_writerJob ) {
         delete m_writerJob;
         m_writerJob = 0;
@@ -737,12 +735,12 @@ bool K3b::DataJob::waitForBurnMedium()
                 // try to get the last track's datamode
                 // we already asked for an appendable cdr when fetching
                 // the ms info
-                kDebug() << "(K3b::DataJob) determining last track's datamode...";
+                qDebug() << "(K3b::DataJob) determining last track's datamode...";
 
                 // FIXME: use the DeviceHandler
                 K3b::Device::Toc toc = d->doc->burner()->readToc();
                 if( toc.isEmpty() ) {
-                    kDebug() << "(K3b::DataJob) could not retrieve toc.";
+                    qDebug() << "(K3b::DataJob) could not retrieve toc.";
                     emit infoMessage( i18n("Unable to determine the last track's datamode. Using default."), MessageError );
                     d->usedDataMode = K3b::DataMode2;
                 }
@@ -752,7 +750,7 @@ bool K3b::DataJob::waitForBurnMedium()
                     else
                         d->usedDataMode = K3b::DataMode2;
 
-                    kDebug() << "(K3b::DataJob) using datamode: "
+                    qDebug() << "(K3b::DataJob) using datamode: "
                              << (d->usedDataMode == K3b::DataMode1 ? "mode1" : "mode2")
                              << endl;
                 }
@@ -813,7 +811,7 @@ bool K3b::DataJob::waitForBurnMedium()
 
         d->usedWritingApp = writingApp();
         // let's default to cdrecord for the time being (except for special cases below)
-        // but prefer growisofs to wodim for DVDs
+        // but prefer growisofs for DVDs
         if ( d->usedWritingApp == K3b::WritingAppAuto ) {
             if (k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "wodim" ))
                 d->usedWritingApp = K3b::WritingAppGrowisofs;
@@ -849,7 +847,7 @@ bool K3b::DataJob::waitForBurnMedium()
             if( foundMedium & K3b::Device::MEDIA_DVD_PLUS_RW &&
                 ( usedMultiSessionMode() == K3b::DataDoc::CONTINUE ||
                   usedMultiSessionMode() == K3b::DataDoc::FINISH ) )
-                emit infoMessage( i18n("Growing ISO9660 filesystem on %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
+                emit infoMessage( i18n("Growing ISO 9660 filesystem on %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
             else
                 emit infoMessage( i18n("Writing %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
         }
@@ -881,7 +879,7 @@ bool K3b::DataJob::waitForBurnMedium()
                     emit infoMessage( i18n("Writing DVD-RW in restricted overwrite mode."), MessageInfo );
                 }
                 else {
-                    emit infoMessage( i18n("Growing ISO9660 filesystem on DVD-RW in restricted overwrite mode."), MessageInfo );
+                    emit infoMessage( i18n("Growing ISO 9660 filesystem on DVD-RW in restricted overwrite mode."), MessageInfo );
                     // we can only do this with growisofs
                     d->usedWritingApp = K3b::WritingAppGrowisofs;
                 }
@@ -940,8 +938,9 @@ bool K3b::DataJob::waitForBurnMedium()
                 d->usedWritingApp = K3b::WritingAppCdrecord;
         }
 
-        if ( d->usedWritingApp == K3b::WritingAppCdrecord &&
-             !k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature( "blu-ray" ) ) {
+        if (d->usedWritingApp == K3b::WritingAppCdrecord &&
+            k3bcore->externalBinManager()->binObject("cdrecord") &&
+            !k3bcore->externalBinManager()->binObject("cdrecord")->hasFeature("blu-ray")) {
             d->usedWritingApp = K3b::WritingAppGrowisofs;
         }
 
@@ -970,7 +969,7 @@ bool K3b::DataJob::waitForBurnMedium()
         if( foundMedium & K3b::Device::MEDIA_BD_RE &&
             ( usedMultiSessionMode() == K3b::DataDoc::CONTINUE ||
               usedMultiSessionMode() == K3b::DataDoc::FINISH ) )
-            emit infoMessage( i18n("Growing ISO9660 filesystem on %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
+            emit infoMessage( i18n("Growing ISO 9660 filesystem on %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
         else
             emit infoMessage( i18n("Writing %1.", Device::mediaTypeString(foundMedium, true)), MessageInfo );
     }
@@ -1006,12 +1005,12 @@ QString K3b::DataJob::jobDetails() const
         !d->doc->dummy() &&
         !(d->doc->multiSessionMode() == K3b::DataDoc::CONTINUE ||
           d->doc->multiSessionMode() == K3b::DataDoc::FINISH) )
-        return i18np("ISO9660 Filesystem (Size: %2) - %1 copy",
-                     "ISO9660 Filesystem (Size: %2) - %1 copies",
+        return i18np("ISO 9660 Filesystem (Size: %2) – One copy",
+                     "ISO 9660 Filesystem (Size: %2) – %1 copies",
                      d->doc->copies(),
                      KIO::convertSize( d->doc->size() ) );
     else
-        return i18n( "ISO9660 Filesystem (Size: %1)",
+        return i18n( "ISO 9660 Filesystem (Size: %1)",
                      KIO::convertSize( d->doc->size() ) );
 }
 
@@ -1024,7 +1023,7 @@ K3b::DataDoc::MultiSessionMode K3b::DataJob::usedMultiSessionMode() const
 
 void K3b::DataJob::cleanup()
 {
-    kDebug();
+    qDebug();
     if( !d->doc->onTheFly() && ( d->doc->removeImages() || d->canceled ) ) {
         if( QFile::exists( d->doc->tempDir() ) ) {
             d->imageFile.remove();
@@ -1047,7 +1046,7 @@ bool K3b::DataJob::hasBeenCanceled() const
 
 bool K3b::DataJob::setupCdrecordJob()
 {
-    kDebug();
+    qDebug();
     K3b::CdrecordWriter* writer = new K3b::CdrecordWriter( d->doc->burner(), this, this );
 
     // cdrecord manpage says that "not all" writers are able to write
@@ -1105,8 +1104,7 @@ bool K3b::DataJob::setupCdrdaoJob()
 
     // now write the tocfile
     if( d->tocFile ) delete d->tocFile;
-    d->tocFile = new KTemporaryFile();
-    d->tocFile->setSuffix( ".toc" );
+    d->tocFile = new QTemporaryFile( "XXXXXX.toc" );
     d->tocFile->open();
 
     QTextStream s( d->tocFile );
@@ -1170,4 +1168,4 @@ bool K3b::DataJob::setupGrowisofsJob()
     return true;
 }
 
-#include "k3bdatajob.moc"
+
