@@ -27,15 +27,14 @@
 #include "k3bthroughputestimator.h"
 #include "k3bglobalsettings.h"
 
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qregexp.h>
-#include <qfile.h>
+#include <QtCore/QDebug>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
+#include <QtCore/QRegExp>
+#include <QtCore/QFile>
+#include "k3b_i18n.h"
 
-#include <klocale.h>
-#include <kdebug.h>
-#include <kglobal.h>
-#include <ktemporaryfile.h>
+#include <QtCore/QTemporaryFile>
 
 
 Q_DECLARE_METATYPE( QProcess::ExitStatus )
@@ -114,11 +113,11 @@ K3b::CdrecordWriter::CdrecordWriter( K3b::Device::Device* dev, K3b::JobHandler*
     d->process.setSplitStdout(true);
     d->process.setSuppressEmptyLines(true);
     d->process.setFlags( K3bQProcess::RawStdin );
-    connect( &d->process, SIGNAL(stdoutLine(const QString&)), this, SLOT(slotStdLine(const QString&)) );
+    connect( &d->process, SIGNAL(stdoutLine(QString)), this, SLOT(slotStdLine(QString)) );
 
     // we use a queued connection to give the process object time to wrap up and return to a correct state
     qRegisterMetaType<QProcess::ExitStatus>();
-    connect( &d->process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(slotProcessExited(int, QProcess::ExitStatus)), Qt::QueuedConnection );
+    connect( &d->process, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(slotProcessExited(int,QProcess::ExitStatus)), Qt::QueuedConnection );
 }
 
 
@@ -141,18 +140,6 @@ QIODevice* K3b::CdrecordWriter::ioDevice() const
 }
 
 
-bool K3b::CdrecordWriter::closeFd()
-{
-    if ( d->process.isRunning() ) {
-        d->process.closeWriteChannel();
-        return true;
-    }
-    else {
-        return false;
-    }
-}
-
-
 void K3b::CdrecordWriter::setDao( bool b )
 {
     d->writingMode = ( b ? K3b::WritingModeSao : K3b::WritingModeTao );
@@ -223,7 +210,9 @@ bool K3b::CdrecordWriter::prepareProcess()
 
     // display progress
     d->process << "-v";
-
+#ifdef K3B_DEBUG
+    d->process << "-V";
+#endif
     if( d->cdrecordBinObject->hasFeature( "gracetime") )
         d->process << "gracetime=2";  // 2 is the lowest allowed value (Joerg, why do you do this to us?)
 
@@ -245,7 +234,7 @@ bool K3b::CdrecordWriter::prepareProcess()
 
     if ( K3b::Device::isBdMedia( d->burnedMediaType ) ) {
         if ( !d->cdrecordBinObject->hasFeature( "blu-ray" ) ) {
-            emit infoMessage( i18n( "Cdrecord version %1 does not support Blu-ray writing." ,d->cdrecordBinObject->version ), MessageError );
+            emit infoMessage( i18n( "Cdrecord version %1 does not support Blu-ray writing." ,d->cdrecordBinObject->version() ), MessageError );
             // FIXME: add a way to fail the whole thing here
         }
         d->process << "-sao";
@@ -341,9 +330,6 @@ bool K3b::CdrecordWriter::prepareProcess()
 
     if( d->rawCdText.size() > 0 ) {
         delete d->cdTextFile;
-        // yes, we do want to use QTemporaryFile and not KTemporaryFile because cdrecord
-        // might be started suid root and the KDE tmp might be on an nfs mounted partition
-        // (Mandriva for example uses ~/tmp)
         d->cdTextFile = new QTemporaryFile();
         if ( !d->cdTextFile->open() ||
              d->cdTextFile->write( d->rawCdText ) != d->rawCdText.size() ||
@@ -368,7 +354,7 @@ bool K3b::CdrecordWriter::prepareProcess()
                 d->process << "-overburn";
         }
         else {
-            emit infoMessage( i18n("Cdrecord %1 does not support overburning.",d->cdrecordBinObject->version), MessageWarning );
+            emit infoMessage( i18n("Cdrecord %1 does not support overburning.",d->cdrecordBinObject->version()), MessageWarning );
         }
     }
 
@@ -411,18 +397,18 @@ void K3b::CdrecordWriter::start()
         return;
     }
 
-    emit debuggingOutput( QLatin1String( "Used versions" ), QLatin1String( "cdrecord: " ) + d->cdrecordBinObject->version );
+    emit debuggingOutput( QLatin1String( "Used versions" ), QString::fromLatin1( "cdrecord: %1" ).arg(d->cdrecordBinObject->version()) );
 
-    if( !d->cdrecordBinObject->copyright.isEmpty() )
-        emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3"
+    if( !d->cdrecordBinObject->copyright().isEmpty() )
+        emit infoMessage( i18n("Using %1 %2 – Copyright © %3"
                                ,(d->cdrecordBinObject->hasFeature( "wodim" ) ? "Wodim" : "Cdrecord" )
-                               ,d->cdrecordBinObject->version
-                               ,d->cdrecordBinObject->copyright), MessageInfo );
+                               ,d->cdrecordBinObject->version()
+                               ,d->cdrecordBinObject->copyright()), MessageInfo );
 
 
-    kDebug() << "***** " << d->cdrecordBinObject->name() << " parameters:\n";
+    qDebug() << "***** " << d->cdrecordBinObject->name() << " parameters:\n";
     QString s = d->process.joinedArgs();
-    kDebug() << s << flush;
+    qDebug() << s << flush;
     emit debuggingOutput( d->cdrecordBinObject->name() + " command:", s);
 
     d->currentTrack = 0;
@@ -451,7 +437,7 @@ void K3b::CdrecordWriter::start()
     if( !d->process.start( KProcess::MergedChannels ) ) {
         // something went wrong when starting the program
         // it "should" be the executable
-        kDebug() << "(K3b::CdrecordWriter) could not start " << d->cdrecordBinObject->name();
+        qDebug() << "(K3b::CdrecordWriter) could not start " << d->cdrecordBinObject->name();
         emit infoMessage( i18n("Could not start %1.",d->cdrecordBinObject->name()), K3b::Job::MessageError );
         jobFinished(false);
     }
@@ -529,11 +515,11 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
                     d->totalSize += track.size;
                 }
                 else
-                    kDebug() << "(K3b::CdrecordWriter) track number parse error: "
+                    qDebug() << "(K3b::CdrecordWriter) track number parse error: "
                              << line.mid( sizeStart, sizeEnd-sizeStart );
             }
             else
-                kDebug() << "(K3b::CdrecordWriter) track number parse error: "
+                qDebug() << "(K3b::CdrecordWriter) track number parse error: "
                          << line.mid( 6, 2 );
         }
 
@@ -546,7 +532,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
             emit buffer( fifo );
             d->lastFifoValue = fifo;
 
-            if( s_progressRx.numCaptures() > 4 )
+            if( s_progressRx.captureCount() > 4 )
                 emit deviceBuffer( s_progressRx.cap(5).toInt() );
 
             //
@@ -562,7 +548,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
                 size = d->tracks[d->currentTrack-1].size;
             }
             else {
-                kError() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!" << endl;
+                qCritical() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!" << endl;
             }
 
             if( !d->writingStarted ) {
@@ -590,8 +576,8 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
     //
 
     else if( line.startsWith( "cdrecord" ) ||
-             line.startsWith( d->cdrecordBinObject->path ) ||
-             line.startsWith( d->cdrecordBinObject->path.left(d->cdrecordBinObject->path.length()-5) ) ) {
+             line.startsWith( d->cdrecordBinObject->path() ) ||
+             line.startsWith( d->cdrecordBinObject->path().left(d->cdrecordBinObject->path().length()-5) ) ) {
         // get rid of the path and the following colon and space
         QString errStr = line.mid( line.indexOf(':') + 2 );
 
@@ -701,7 +687,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
             if( d->tracks.count() > d->currentTrack-1 )
                 d->alreadyWritten += d->tracks[d->currentTrack-1].size;
             else
-                kError() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!";
+                qCritical() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!";
         }
         else
             emit infoMessage( i18n("Starting disc write"), MessageInfo );
@@ -709,14 +695,14 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
         d->currentTrack++;
 
         if( d->currentTrack > d->tracks.count() ) {
-            kDebug() << "(K3b::CdrecordWriter) need to add dummy track struct.";
+            qDebug() << "(K3b::CdrecordWriter) need to add dummy track struct.";
             struct Private::Track t;
             t.size = 1;
             t.audio = false;
             d->tracks.append(t);
         }
 
-        kDebug() << "(K3b::CdrecordWriter) writing track " << d->currentTrack << " of " << d->totalTracks << " tracks.";
+        qDebug() << "(K3b::CdrecordWriter) writing track " << d->currentTrack << " of " << d->totalTracks << " tracks.";
         emit nextTrack( d->currentTrack, d->totalTracks );
     }
     else if( line.startsWith( "Fixating" ) ) {
@@ -747,7 +733,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
     else if( line.startsWith( "Re-load disk and hit" ) ) {
         // this happens on some notebooks where cdrecord is not able to close the
         // tray itself, so we need to ask the user to do so
-        blockingInformation( i18n("Please reload the medium and press 'ok'"),
+        blockingInformation( i18n("Please reload the medium and press 'OK'"),
                              i18n("Unable to close the tray") );
 
         // now send a <CR> to cdrecord
@@ -774,7 +760,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
     }
     else {
         // debugging
-        kDebug() << "(" << d->cdrecordBinObject->name() << ") " << line;
+        qDebug() << "(" << d->cdrecordBinObject->name() << ") " << line;
     }
 }
 
@@ -821,7 +807,7 @@ void K3b::CdrecordWriter::slotProcessExited( int exitCode, QProcess::ExitStatus
         break;
 
         default:
-            kDebug() << "(K3b::CdrecordWriter) error: " << exitCode;
+            qDebug() << "(K3b::CdrecordWriter) error: " << exitCode;
 
             if( d->cdrecordError == UNKNOWN && d->lastFifoValue <= 3 )
                 d->cdrecordError = BUFFER_UNDERRUN;
@@ -867,9 +853,7 @@ void K3b::CdrecordWriter::slotProcessExited( int exitCode, QProcess::ExitStatus
                 break;
             case PERMISSION_DENIED:
                 emit infoMessage( i18n("%1 has no permission to open the device.",QString("cdrecord")), MessageError );
-#ifdef BUILD_K3BSETUP
-                emit infoMessage( i18n("You may use K3bsetup to solve this problem."), MessageError );
-#endif
+                emit infoMessage( i18n("Modify device settings in K3b to solve this problem."), MessageError );
                 break;
             case BUFFER_UNDERRUN:
                 emit infoMessage( i18n("Probably a buffer underrun occurred."), MessageError );
@@ -950,4 +934,4 @@ qint64 K3b::CdrecordWriter::write( const char* data, qint64 maxSize )
     return d->process.write( data, maxSize );
 }
 
-#include "k3bcdrecordwriter.moc"
+
