@@ -18,6 +18,7 @@
 #include <errno.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdio.h>
 
 #include "isofs.h"
 #include "rock.h"
@@ -287,29 +288,29 @@ void FreeRR(rr_entry *rrentry) {
 	}
 	if (rrentry->sl) {
 		free(rrentry->sl);
-		rrentry->name=NULL;
+		rrentry->sl = NULL;
 	}
 }
 
-static int str_nappend(char **d,char *s,int n) {
-	int i=0;
+int str_nappend(char **d, char *s, int n) 
+{
+	int i = 0;
 	char *c;
 
-/*	i=strnlen(s,n)+1; */
-	while (i<n && s[i]) i++;
+	while (i < n && s[i]) i++;
 	i++;
-	if (*d) i+=(strlen(*d)+1);
-	c=(char*) malloc(i);
+	if (*d) i += (strlen(*d) + 1);
+	c = (char*) malloc(i);
 	if (!c) return -ENOMEM;
 	if (*d) {
-		strcpy(c,*d);
-		strncat(c,s,n);
+		strcpy(c, *d);
+		strncat(c, s, n);
 
 		free(*d);
 	} else
-		strncpy(c,s,n);
-	c[i-1]=0;
-	*d=c;
+		strncpy(c, s, n);
+	c[i - 1] = 0;
+	*d = c;
 	return 0;
 }
 
