@@ -87,6 +87,7 @@ K3b::SystemProblem::SystemProblem( Type t,
 K3b::SystemProblemDialog::SystemProblemDialog( const QList<K3b::SystemProblem>& problems,
                                                bool showDeviceSettingsButton,
                                                bool showBinSettingsButton,
+                                               bool forceCheck,
                                                QWidget* parent)
     : QDialog( parent )
 {
@@ -113,6 +114,7 @@ K3b::SystemProblemDialog::SystemProblemDialog( const QList<K3b::SystemProblem>&
     buttonBox->addButton( QDialogButtonBox::Close );
 
     m_checkDontShowAgain = new QCheckBox( i18n("Do not show again"), this );
+    m_checkDontShowAgain->setVisible(!forceCheck);
 
     // setup the problem view
     // ---------------------------------------------------------------------------------------------------
@@ -169,12 +171,15 @@ void K3b::SystemProblemDialog::done(int r)
 }
 
 
-void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel level )
+void K3b::SystemProblemDialog::checkSystem(QWidget* parent, NotificationLevel level, bool forceCheck)
 {
     QList<K3b::SystemProblem> problems;
     bool showDeviceSettingsButton = false;
     bool showBinSettingsButton = false;
 
+    if (!forceCheck && !readCheckSystemConfig())
+        return;
+
     if( k3bcore->deviceManager()->allDevices().isEmpty() ) {
         problems.append( K3b::SystemProblem( K3b::SystemProblem::CRITICAL,
                                            i18n("No optical drive found."),
@@ -289,10 +294,11 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         }
 
         if (!k3bcore->externalBinManager()->foundBin("cdrskin")) {
-            problems.append(K3b::SystemProblem(K3b::SystemProblem::CRITICAL,
+            problems.append(K3b::SystemProblem(K3b::SystemProblem::NON_CRITICAL,
                 i18n("Unable to find %1 executable", QString("cdrskin")),
-                i18n("K3b uses cdrskin in place of cdrecord."),
-                i18n("Install the libburn package which contains cdrskin")));
+                i18n("Cdrskin can substitute for cdrecord with data and audio"
+                     " CD, and for growisofs with DVD and BD."),
+                i18n("Consider to install the libburn and cdrskin packages.")));
         }
     }
 
@@ -621,7 +627,7 @@ void K3b::SystemProblemDialog::checkSystem( QWidget* parent, NotificationLevel l
         static K3b::SystemProblemDialog* s_openDlg = 0;
         if( s_openDlg )
             s_openDlg->close();
-        K3b::SystemProblemDialog dlg( problems, showDeviceSettingsButton, showBinSettingsButton, parent );
+        K3b::SystemProblemDialog dlg( problems, showDeviceSettingsButton, showBinSettingsButton, forceCheck, parent );
         s_openDlg = &dlg;
         dlg.exec();
         s_openDlg = 0;
@@ -711,13 +717,13 @@ QList<K3b::Device::Device*> K3b::SystemProblemDialog::checkForAutomounting()
 
 bool K3b::SystemProblemDialog::readCheckSystemConfig()
 {
-    KConfigGroup cfgGrp( KSharedConfig::openConfig(), "General Options" );
+    KConfigGroup cfgGrp(KSharedConfig::openConfig(), "General Options");
 
-    K3b::Version configVersion( cfgGrp.readEntry( "Last system check version", "0.1" ) );
-    if( configVersion < k3bcore->version() )
-        cfgGrp.writeEntry( "check system config", true );
+    K3b::Version configVersion(cfgGrp.readEntry( "Last system check version", "0.1" ));
+    if (configVersion < k3bcore->version())
+        cfgGrp.writeEntry("check system config", true);
 
-    return cfgGrp.readEntry( "check system config", true );
+    return cfgGrp.readEntry("check system config", false);
 }
 
 
