@@ -34,33 +34,30 @@
 #include "k3bapplication.h"
 #include "k3bmediacache.h"
 
-#include <kguiitem.h>
-#include <klocale.h>
-#include <KStandardGuiItem>
-#include <kstandarddirs.h>
-#include <kmessagebox.h>
-#include <kconfig.h>
-#include <kapplication.h>
-#include <kiconloader.h>
+#include <KConfigCore/KConfig>
+#include <KConfigCore/KSharedConfig>
+#include <KIconThemes/KIconLoader>
+#include <KI18n/KLocalizedString>
+#include <KWidgetsAddons/KGuiItem>
+#include <KWidgetsAddons/KMessageBox>
+#include <KWidgetsAddons/KStandardGuiItem>
 
-#include <qcheckbox.h>
-#include <qspinbox.h>
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qgroupbox.h>
-#include <qlist.h>
-#include <qlabel.h>
-#include <qtooltip.h>
-#include <qtabwidget.h>
-
-
-#include <qpushbutton.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qsizepolicy.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <QGridLayout>
+#include <QtCore/QFile>
+#include <QtCore/QFileInfo>
+#include <QtCore/QList>
+#include <QtWidgets/QButtonGroup>
+#include <QtWidgets/QCheckBox>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QGridLayout>
+#include <QtWidgets/QGroupBox>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QRadioButton>
+#include <QtWidgets/QSizePolicy>
+#include <QtWidgets/QSpinBox>
+#include <QtWidgets/QToolTip>
+#include <QtWidgets/QTabWidget>
 
 
 K3b::MediaCopyDialog::MediaCopyDialog( QWidget *parent )
@@ -74,7 +71,7 @@ K3b::MediaCopyDialog::MediaCopyDialog( QWidget *parent )
     QWidget* main = mainWidget();
 
     QGridLayout* mainGrid = new QGridLayout( main );
-    mainGrid->setMargin( 0 );
+    mainGrid->setContentsMargins( 0, 0, 0, 0 );
 
     QGroupBox* groupSource = new QGroupBox( i18n("Source Medium"), main );
     m_comboSourceDevice = new K3b::MediaSelectionComboBox( groupSource );
@@ -222,7 +219,7 @@ K3b::MediaCopyDialog::MediaCopyDialog( QWidget *parent )
                                             "protection based on corrupted sectors.") );
     m_checkReadCdText->setWhatsThis( i18n("<p>If this option is checked K3b will search for CD-Text on the source CD. "
                                           "Disable it if your CD drive has problems with reading CD-Text or you want "
-                                          "to stick to Cddb info.") );
+                                          "to stick to CDDB info.") );
     m_checkIgnoreDataReadErrors->setWhatsThis( i18n("<p>If this option is checked and K3b is not able to read a data sector from the "
                                                     "source medium it will be replaced with zeros on the resulting copy.") );
 
@@ -231,11 +228,11 @@ K3b::MediaCopyDialog::MediaCopyDialog( QWidget *parent )
        + i18n("<p>This is the normal copy mode for DVD, Blu-ray, and most CD media types. "
                "It allows copying Audio CDs, multi and single session Data Media, and "
                "Enhanced Audio CDs (an Audio CD containing an additional data session)."
-               "<p>For VideoCDs please use the CD Cloning mode.")
+               "<p>For Video CDs please use the CD Cloning mode.")
         + "<p><b>" + i18n("Clone Copy") + "</b>"
         + i18n("<p>In CD Cloning mode K3b performs a raw copy of the CD. That means it does "
                "not care about the content but simply copies the CD bit by bit. It may be used "
-               "to copy VideoCDs or CDs which contain erroneous sectors."
+               "to copy Video CDs or CDs which contain erroneous sectors."
                "<p><b>Caution:</b> Only single session CDs can be cloned.") );
 }
 
@@ -282,17 +279,15 @@ void K3b::MediaCopyDialog::slotStartClicked()
     K3b::Medium burnMedium = k3bappcore->mediaCache()->medium( burnDev );
 
     K3b::JobProgressDialog* dlg = 0;
-    if( m_checkOnlyCreateImage->isChecked() ) {
-        dlg = new K3b::JobProgressDialog( parentWidget() );
-    }
-    else {
-        dlg = new K3b::BurnProgressDialog( parentWidget() );
-    }
+    if (m_checkOnlyCreateImage->isChecked())
+        dlg = new K3b::JobProgressDialog(parentWidget());
+    else
+        dlg = new K3b::BurnProgressDialog(parentWidget());
+    dlg->setAttribute(Qt::WA_DeleteOnClose);    // Memory-leak issue fixed!
 
     K3b::BurnJob* burnJob = 0;
 
     if( m_comboCopyMode->currentIndex() == 1 ) {
-
         //
         // check for m_tempDirSelectionWidget->tempPath() and
         // m_tempDirSelectionWidget-tempPath() + ".toc"
@@ -382,10 +377,9 @@ void K3b::MediaCopyDialog::slotStartClicked()
 
     dlg->startJob( burnJob );
 
-    delete dlg;
     delete burnJob;
 
-    if( KConfigGroup( KGlobal::config(), "General Options" ).readEntry( "keep action dialogs open", false ) )
+    if( KConfigGroup( KSharedConfig::openConfig(), "General Options" ).readEntry( "keep action dialogs open", false ) )
         show();
     else
         close();
@@ -487,16 +481,17 @@ void K3b::MediaCopyDialog::toggleAll()
             }
             else if ( sourceMedium.diskInfo().mediaType() & K3b::Device::MEDIA_DVD_ALL ) {
                 // only auto for DVD+R(W)
-                if( burnDev->writeCapabilities() & (K3b::Device::MEDIA_DVD_R|K3b::Device::MEDIA_DVD_RW) ) {
-                    modes |= K3b::WritingModeSao|K3b::WritingModeRestrictedOverwrite;
-                    if( burnDev->featureCurrent( K3b::Device::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) != 0 )
-                        modes |= K3b::WritingModeIncrementalSequential;
-                }
+                if (burnDev) {
+                    if( burnDev->writeCapabilities() & (K3b::Device::MEDIA_DVD_R|K3b::Device::MEDIA_DVD_RW) ) {
+                        modes |= K3b::WritingModeSao|K3b::WritingModeRestrictedOverwrite;
+                        if( burnDev->featureCurrent( K3b::Device::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) != 0 )
+                            modes |= K3b::WritingModeIncrementalSequential;
+                    }
 
-                // TODO: once we have layer jump support: this is where it goes
-//               if ( burnDev->supportsWritingMode( K3b::Device::WRITING_MODE_LAYER_JUMP ) ) {
-//                   modes |= K3b::Device::WRITING_MODE_LAYER_JUMP;
-//               }
+                    // TODO: once we have layer jump support: this is where it goes
+                    //if ( burnDev->supportsWritingMode( K3b::Device::WRITING_MODE_LAYER_JUMP ) )
+                    //     modes |= K3b::Device::WRITING_MODE_LAYER_JUMP;
+                }
             }
             else if ( sourceMedium.diskInfo().mediaType() & K3b::Device::MEDIA_BD_ALL ) {
                 // no modes, only auto
@@ -638,4 +633,4 @@ KIO::filesize_t K3b::MediaCopyDialog::neededSize() const
         return medium.diskInfo().size().rawBytes();
 }
 
-#include "k3bmediacopydialog.moc"
+
