@@ -15,12 +15,10 @@
 #ifndef K3BAUDIOTRACKDIALOG_H
 #define K3BAUDIOTRACKDIALOG_H
 
-
-#include <kdialog.h>
-
 #include "k3bmsf.h"
 
 #include <QtCore/QList>
+#include <QtWidgets/QDialog>
 
 namespace K3b {
     class AudioTrack;
@@ -29,7 +27,7 @@ namespace K3b {
     /**
      *@author Sebastian Trueg
      */
-    class AudioTrackDialog : public KDialog
+    class AudioTrackDialog : public QDialog
     {
         Q_OBJECT
 
@@ -38,7 +36,7 @@ namespace K3b {
         ~AudioTrackDialog();
 
     protected Q_SLOTS:
-        void slotOk();
+        void accept() override;
         void slotApply();
 
         void updateTrackLengthDisplay();
@@ -47,8 +45,6 @@ namespace K3b {
         QList<AudioTrack*> m_tracks;
 
         AudioTrackWidget* m_audioTrackWidget;
-
-        void setupGui();
     };
 }
 
