@@ -15,10 +15,10 @@
 #ifndef _K3B_VIDEOCD_OPTIONS_H_
 #define _K3B_VIDEOCD_OPTIONS_H_
 
+#include "k3bglobals.h"
+
 #include <KI18n/KLocalizedString>
 #include <QtCore/QString>
-#include <QFileInfo>
-#include <QStandardPaths>
 
 namespace K3b {
 class VideoCdRippingOptions
@@ -27,6 +27,7 @@ class VideoCdRippingOptions
         VideoCdRippingOptions()
             :   m_videocdsize( 0 ),
                 m_videocdsource( "/dev/cdrom" ),
+                m_videocddestination(K3b::defaultTempPath()),
                 m_videocddescription( i18n( "Video CD" ) ),
                 m_videocdripfiles( false ),
                 m_videocdripsegments( false ),
@@ -34,13 +35,7 @@ class VideoCdRippingOptions
                 m_ignoreExt( false ),
                 m_sector2336( false ),
                 m_extractXML( false )
-        {
-            m_videocddestination = QStandardPaths::writableLocation(QStandardPaths::MoviesLocation);
-            QFileInfo checkPath(m_videocddestination);
-            if (! checkPath.exists()) {
-                m_videocddestination = QStandardPaths::writableLocation(QStandardPaths::HomeLocation);
-            }
-        }
+        {}
 
         void setVideoCdSize( unsigned long size ) { m_videocdsize = size;}
         void setVideoCdSource( const QString& source ) { m_videocdsource = source;}
